==> hx_components_flutter-1.0.0.tar.gz: lib/src/widgets/hx_alert_dialog.dart <==
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_utils.dart';
import 'package:hx_components_flutter/src/widgets/hx_button.dart';
import 'package:hx_components_flutter/src/widgets/hx_text.dart';

class HxAlertDialog extends StatelessWidget {
  final String titulo;
  final String mensagem;
  final String textoBotaoConfirmar;
  final String textoBotaoCancelar;

  const HxAlertDialog({
    super.key,
    required this.titulo,
    required this.mensagem,
    this.textoBotaoConfirmar = 'Sim',
    this.textoBotaoCancelar = 'Não',
  });

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      elevation: 4,
      insetPadding: const EdgeInsets.only(top: 24),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(20),
      ),
      contentPadding: const EdgeInsets.all(24),
      actionsPadding: const EdgeInsets.only(
        bottom: 20,
        left: 24,
        right: 24,
      ),
      title: HxText.heading1('Confirmar', color: kcPrimaryColor),
      content: HxText.body('Deseja realmente confirmar esta ação?'),
      actions: [
        Column(
          children: [
            const Divider(),
            const SizedBox(
              height: 20,
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Expanded(
                  child: SizedBox(
                    height: 48,
                    child: HxButton.secondary(
                      wrapAroundContent: false,
                      title: textoBotaoCancelar,
                      onTap: () {
                        Navigator.of(context).pop(false);
                      },
                    ),
                  ),
                ),
                const SizedBox(
                  width: 16,
                ),
                Expanded(
                  child: SizedBox(
                    height: 48,
                    child: HxButton(
                      wrapAroundContent: false,
                      title: textoBotaoConfirmar,
                      onTap: () {
                        Navigator.of(context).pop(true);
                      },
                    ),
                  ),
                ),
              ],
            ),
          ],
        )
      ],
    );
  }
}

==> hx_components_flutter-1.0.7.tar.gz: lib/src/widgets/hx_alert_dialog.dart <==
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_utils.dart';
import 'package:hx_components_flutter/src/widgets/hx_button.dart';
import 'package:hx_components_flutter/src/widgets/hx_text.dart';

class HxAlertDialog extends StatelessWidget {
  final String titulo;
  final String mensagem;
  final String textoBotaoConfirmar;
  final String textoBotaoCancelar;

  const HxAlertDialog({
    super.key,
    required this.titulo,
    required this.mensagem,
    this.textoBotaoConfirmar = 'Sim',
    this.textoBotaoCancelar = 'Não',
  });

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      elevation: 4,
      insetPadding: const EdgeInsets.only(top: 24),
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(20),
      ),
      contentPadding: const EdgeInsets.all(24),
      actionsPadding: const EdgeInsets.only(
        bottom: 20,
        left: 24,
        right: 24,
      ),
      title: HxText.heading1('Confirmar', color: kcPrimaryColor),
      content: HxText('Deseja realmente confirmar esta ação?'),
      actions: [
        Column(
          children: [
            const Divider(),
            const SizedBox(
              height: 20,
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Expanded(
                  child: HxButton.secondary(
                    title: textoBotaoCancelar,
                    onTap: () {
                      Navigator.of(context).pop(false);
                    },
                  ),
                ),
                const SizedBox(
                  width: 16,
                ),
                Expanded(
                  child: HxButton.primary(
                    title: textoBotaoConfirmar,
                    onTap: () {
                      Navigator.of(context).pop(true);
                    },
                  ),
                ),
              ],
            ),
          ],
        )
      ],
    );
  }
}
